@@ -18,12 +18,18 @@ class CollataAndPad(object):
         remap_names:
             If a dictionary the stanard output names (input_ids, labels, attention_mask) will be maped
             to whatever is in the dict.
+        mlm (`float`, `optional`, defaults to None):
+            Number [0, 1] - Marks the mlm probability, if it is not None tokens will be masked
+        mlm_mask_id:
+            ID of the token that will be used as a mask
     '''
-    def __init__(self, max_len=-1, pad_id=0, shift_labels=False, remap_names=None):
+    def __init__(self, max_len=-1, pad_id=0, shift_labels=False, remap_names=None, mlm=None, mlm_mask_id=None):
         self.max_len = max_len
         self.pad_id = pad_id
         self.shift_labels = shift_labels
         self.remap_names = remap_names
+        self.mlm = mlm
+        self.mlm_mask_id = mlm_mask_id
 
 
     def __call__(self, features: List[InputDataClass]) -> Dict[str, torch.Tensor]:
@@ -48,6 +54,7 @@ class CollataAndPad(object):
             # Labels already exist, just pad them with -100
             batch['labels'] = torch.tensor([f['labels'] for f in features], dtype=torch.long)
 
+
         batch['input_ids'] = torch.tensor([f['input_ids'][0:max_len] + [self.pad_id] * max(0, max_len - len(f['input_ids']))
                                           for f in features], dtype=torch.long)
         batch['attention_mask'] = batch['input_ids'] != self.pad_id
@@ -57,8 +64,16 @@ class CollataAndPad(object):
             batch['labels'] = batch['input_ids'].clone()
             batch['labels'][batch['labels'] == self.pad_id] = -100
 
+        # If we want Masked Langauge Modeling - mask some tokens
+        if self.mlm is not None:
+            pass
+
         if self.remap_names is not None:
             batch = {self.remap_names.get(k, k):v for k,v in batch.items()}
 
         return batch
 
+
+    def mask_tokens(self, input_ids):
+        probability_matrix = torch.full(input_ids.shape, self.mlm_probability)
+
