@@ -126,21 +126,25 @@ class ComputePrecisionHF(object):
     r''' Used for computing precison when working with HF trainer
     '''
 
-    def __init__(self, id2tkn, id2type, batch_size=1000, **kwargs):
+    def __init__(self, id2tkn, id2type, batch_size=1000, topk=1, **kwargs):
         self.id2tkn = id2tkn
         self.id2type = id2type
         self.batch_size = batch_size
         self.kwargs = kwargs
+        self.topk = topk
 
     def __call__(self, p):
         # We will do this in batches, because it can be very memory demanding
         metrics_data = None
         start = 0
         while start < len(p.predictions):
-            predictions = np.argmax(p.predictions[start:start+self.batch_size], axis=2) # For speed do not send predictions as scores
+            predictions = p.predictions[start:start+self.batch_size]
             label_ids = p.label_ids[start:start+self.batch_size]
+            if self.topk == 1:
+                # For speed do not send predictions as scores
+                predictions = np.argmax(predictions, axis=2)
             metrics_data = precision(predictions, label_ids=label_ids, id2tkn=self.id2tkn, id2type=self.id2type, old_data=metrics_data,
-                                     predictions_are_scores=False, **self.kwargs)
+                                     predictions_are_scores=self.topk!=1, topk=self.topk, **self.kwargs)
             start += self.batch_size
 
         return {
